// Copyright (C) 2010 Florent Lamiraux, Thomas Moulard, JRL, CNRS/AIST.
//
// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program.  If not, see <http://www.gnu.org/licenses/>.

#ifndef ABSTRACT_GIK_TASK_CONFIG_HH
# define ABSTRACT_GIK_TASK_CONFIG_HH

// Package version (header).
# define ABSTRACT_GIK_TASK_VERSION "2.7"

// Handle portable symbol export.
// Defining manually which symbol should be exported is required
// under Windows whether MinGW or MSVC is used.
//
// The headers then have to be able to work in two different modes:
// - dllexport when one is building the library,
// - dllimport for clients using the library.
//
// On Linux, set the visibility accordingly. If C++ symbol visibility
// is handled by the compiler, see: http://gcc.gnu.org/wiki/Visibility
# if defined _WIN32 || defined __CYGWIN__
// On Microsoft Windows, use dllimport and dllexport to tag symbols.
#  define ABSTRACT_GIK_TASK_DLLIMPORT __declspec(dllimport)
#  define ABSTRACT_GIK_TASK_DLLEXPORT __declspec(dllexport)
#  define ABSTRACT_GIK_TASK_DLLLOCAL
# else
// On Linux, for GCC >= 4, tag symbols using GCC extension.
#  if __GNUC__ >= 4
#   define ABSTRACT_GIK_TASK_DLLIMPORT __attribute__ ((visibility("default")))
#   define ABSTRACT_GIK_TASK_DLLEXPORT __attribute__ ((visibility("default")))
#   define ABSTRACT_GIK_TASK_DLLLOCAL  __attribute__ ((visibility("hidden")))
#  else
// Otherwise (GCC < 4 or another compiler is used), export everything.
#   define ABSTRACT_GIK_TASK_DLLIMPORT
#   define ABSTRACT_GIK_TASK_DLLEXPORT
#   define ABSTRACT_GIK_TASK_DLLLOCAL
#  endif // __GNUC__ >= 4
# endif // defined _WIN32 || defined __CYGWIN__

# ifdef ABSTRACT_GIK_TASK_STATIC
// If one is using the library statically, get rid of
// extra information.
#  define ABSTRACT_GIK_TASK_DLLAPI
#  define ABSTRACT_GIK_TASK_LOCAL
# else
// Depending on whether one is building or using the
// library define DLLAPI to import or export.
#  ifdef abstract_gik_task_EXPORTS
#   define ABSTRACT_GIK_TASK_DLLAPI ABSTRACT_GIK_TASK_DLLEXPORT
#  else
#   define ABSTRACT_GIK_TASK_DLLAPI ABSTRACT_GIK_TASK_DLLIMPORT
#  endif // ABSTRACT_GIK_TASK_EXPORTS
#  define ABSTRACT_GIK_TASK_LOCAL ABSTRACT_GIK_TASK_DLLLOCAL
# endif // ABSTRACT_GIK_TASK_STATIC
#endif //! ABSTRACT_GIK_TASK_CONFIG_HH
